@@ -237,6 +237,10 @@ function configure_manila {
         iniset $MANILA_CONF DEFAULT migration_driver_continue_update_interval $MANILA_SHARE_MIGRATION_PERIOD_TASK_INTERVAL
     fi
 
+    if ! [[ -z $MANILA_SERVER_MIGRATION_PERIOD_TASK_INTERVAL ]]; then
+        iniset $MANILA_CONF DEFAULT server_migration_driver_continue_update_interval $MANILA_SERVER_MIGRATION_PERIOD_TASK_INTERVAL
+    fi
+
     if ! [[ -z $MANILA_DATA_COPY_CHECK_HASH ]]; then
         iniset $MANILA_CONF DEFAULT check_hash $MANILA_DATA_COPY_CHECK_HASH
     fi
@@ -263,7 +267,9 @@ function configure_manila {
     if is_service_enabled cinder; then
         configure_keystone_authtoken_middleware $MANILA_CONF cinder cinder
     fi
-
+    if is_service_enabled glance; then
+        configure_keystone_authtoken_middleware $MANILA_CONF glance glance
+    fi
     # Note: set up config group does not mean that this backend will be enabled.
     # To enable it, specify its name explicitly using "enabled_share_backends" opt.
     configure_default_backends
@@ -361,13 +367,7 @@ function create_service_share_servers {
                 fi
 
                 floating_ip=$(openstack floating ip create $PUBLIC_NETWORK_NAME --subnet $PUBLIC_SUBNET_NAME | grep 'floating_ip_address' | get_field 2)
-                # TODO(rishabh-d-dave): For time being circumvent the bug -
-                # https://bugs.launchpad.net/python-openstackclient/+bug/1747721
-                # Once fixed, replace the following 3 lines by -
-                # openstack server add floating ip $vm_id $floating_ip
-                vm_port_id=$(openstack port list --server $vm_id -c ID -f \
-                    value)
-                openstack floating ip set --port $vm_port_id $floating_ip
+                openstack server add floating ip $vm_id $floating_ip
 
                 iniset $MANILA_CONF $BE service_instance_name_or_id $vm_id
                 iniset $MANILA_CONF $BE service_net_name_or_ip $floating_ip
@@ -949,7 +949,7 @@ function update_tempest {
 
         # Max API micro-version for tempest tests
         iniset $TEMPEST_CONFIG share min_api_microversion 2.0
-        iniset $TEMPEST_CONFIG share max_api_microversion 2.55
+        iniset $TEMPEST_CONFIG share max_api_microversion 2.57
     fi
 }
 
