@@ -13,8 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+# The maximum value a signed INT type may have
+DB_MAX_INT = 0x7FFFFFFF
+
 # SHARE AND GENERAL STATUSES
 STATUS_CREATING = 'creating'
+STATUS_CREATING_FROM_SNAPSHOT = 'creating_from_snapshot'
 STATUS_DELETING = 'deleting'
 STATUS_DELETED = 'deleted'
 STATUS_ERROR = 'error'
@@ -24,6 +28,7 @@ STATUS_INACTIVE = 'inactive'
 STATUS_MANAGING = 'manage_starting'
 STATUS_MANAGE_ERROR = 'manage_error'
 STATUS_UNMANAGING = 'unmanage_starting'
+STATUS_MANAGE_ERROR_UNMANAGING = 'manage_error_unmanage_starting'
 STATUS_UNMANAGE_ERROR = 'unmanage_error'
 STATUS_UNMANAGED = 'unmanaged'
 STATUS_EXTENDING = 'extending'
@@ -58,6 +63,10 @@ STATUS_NEW = 'new'
 STATUS_OUT_OF_SYNC = 'out_of_sync'
 STATUS_ACTIVE = 'active'
 
+# Share server migration statuses
+STATUS_SERVER_MIGRATING = 'server_migrating'
+STATUS_SERVER_MIGRATING_TO = 'server_migrating_to'
+
 ACCESS_RULES_STATES = (
     ACCESS_STATE_QUEUED_TO_APPLY,
     ACCESS_STATE_QUEUED_TO_DENY,
@@ -67,16 +76,18 @@ ACCESS_RULES_STATES = (
     ACCESS_STATE_ERROR,
     ACCESS_STATE_DELETED,
 )
-
+# Share and share server migration task states
 TASK_STATE_MIGRATION_STARTING = 'migration_starting'
 TASK_STATE_MIGRATION_IN_PROGRESS = 'migration_in_progress'
 TASK_STATE_MIGRATION_COMPLETING = 'migration_completing'
 TASK_STATE_MIGRATION_SUCCESS = 'migration_success'
 TASK_STATE_MIGRATION_ERROR = 'migration_error'
 TASK_STATE_MIGRATION_CANCELLED = 'migration_cancelled'
+TASK_STATE_MIGRATION_CANCEL_IN_PROGRESS = 'migration_cancel_in_progress'
 TASK_STATE_MIGRATION_DRIVER_STARTING = 'migration_driver_starting'
 TASK_STATE_MIGRATION_DRIVER_IN_PROGRESS = 'migration_driver_in_progress'
 TASK_STATE_MIGRATION_DRIVER_PHASE1_DONE = 'migration_driver_phase1_done'
+# Share statuses used by data service and host assisted migration
 TASK_STATE_DATA_COPYING_STARTING = 'data_copying_starting'
 TASK_STATE_DATA_COPYING_IN_PROGRESS = 'data_copying_in_progress'
 TASK_STATE_DATA_COPYING_COMPLETING = 'data_copying_completing'
@@ -109,6 +120,7 @@ TRANSITIONAL_STATUSES = (
     STATUS_EXTENDING, STATUS_SHRINKING,
     STATUS_MIGRATING, STATUS_MIGRATING_TO,
     STATUS_RESTORING, STATUS_REVERTING,
+    STATUS_SERVER_MIGRATING, STATUS_SERVER_MIGRATING_TO,
 )
 
 INVALID_SHARE_INSTANCE_STATUSES_FOR_ACCESS_RULE_UPDATES = (
@@ -178,6 +190,33 @@ TASK_STATE_STATUSES = (
     None,
 )
 
+SERVER_TASK_STATE_STATUSES = (
+    TASK_STATE_MIGRATION_STARTING,
+    TASK_STATE_MIGRATION_IN_PROGRESS,
+    TASK_STATE_MIGRATION_COMPLETING,
+    TASK_STATE_MIGRATION_SUCCESS,
+    TASK_STATE_MIGRATION_ERROR,
+    TASK_STATE_MIGRATION_CANCEL_IN_PROGRESS,
+    TASK_STATE_MIGRATION_CANCELLED,
+    TASK_STATE_MIGRATION_DRIVER_IN_PROGRESS,
+    TASK_STATE_MIGRATION_DRIVER_PHASE1_DONE,
+    None,
+)
+
+SHARE_SERVER_STATUSES = (
+    STATUS_ACTIVE,
+    STATUS_ERROR,
+    STATUS_DELETING,
+    STATUS_CREATING,
+    STATUS_MANAGING,
+    STATUS_UNMANAGING,
+    STATUS_UNMANAGE_ERROR,
+    STATUS_MANAGE_ERROR,
+    STATUS_INACTIVE,
+    STATUS_SERVER_MIGRATING,
+    STATUS_SERVER_MIGRATING_TO,
+)
+
 REPLICA_STATE_ACTIVE = 'active'
 REPLICA_STATE_IN_SYNC = 'in_sync'
 REPLICA_STATE_OUT_OF_SYNC = 'out_of_sync'
