@@ -105,6 +105,7 @@ class Service(service.Service):
         LOG.info('Starting %(topic)s node (version %(version_string)s)',
                  {'topic': self.topic, 'version_string': version_string})
         self.model_disconnected = False
+        self.manager.init_host()
         ctxt = context.get_admin_context()
 
         if self.coordinator:
@@ -126,7 +127,8 @@ class Service(service.Service):
         self.rpcserver = rpc.get_server(target, endpoints)
         self.rpcserver.start()
 
-        self.manager.init_host()
+        self.manager.init_host_with_rpc()
+
         if self.report_interval:
             pulse = loopingcall.FixedIntervalLoopingCall(self.report_state)
             pulse.start(interval=self.report_interval,
@@ -245,6 +247,14 @@ class Service(service.Service):
 
     def report_state(self):
         """Update the state of this service in the datastore."""
+        if not self.manager.is_service_ready():
+            # NOTE(haixin): If the service is still initializing or failed to
+            #               intialize.
+            LOG.error('Manager for service %s is not ready yet, skipping state'
+                      ' update routine. Service will appear "down".',
+                      self.binary)
+            return
+
         ctxt = context.get_admin_context()
         state_catalog = {}
         try:
